@@ -1,4 +1,8 @@
 
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
+#endif
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/sysctl.h>
@@ -401,7 +405,7 @@ SEXP psll_cpu_times(SEXP p) {
   REAL(result)[0] = (double) pti.pti_total_user / 1000000000.0;
   REAL(result)[1] = (double) pti.pti_total_system / 1000000000.0;
   REAL(result)[2] = REAL(result)[3] = NA_REAL;
-  PROTECT(names = ps__build_string("user", "system", "childen_user",
+  PROTECT(names = ps__build_string("user", "system", "children_user",
 				   "children_system", NULL));
   setAttrib(result, R_NamesSymbol, names);
 
@@ -456,6 +460,26 @@ SEXP ps__boot_time() {
   return ScalarReal(unixtime);
 }
 
+SEXP ps__cpu_count_logical() {
+  int num = 0;
+  size_t size = sizeof(int);
+
+  if (sysctlbyname("hw.logicalcpu", &num, &size, NULL, 2))
+    return ScalarInteger(NA_INTEGER);
+  else 
+    return ScalarInteger(num);
+}
+
+SEXP ps__cpu_count_physical() {
+  int num = 0;
+  size_t size = sizeof(int);
+  
+  if (sysctlbyname("hw.physicalcpu", &num, &size, NULL, 0))
+    return ScalarInteger(NA_INTEGER);
+  else 
+    return ScalarInteger(num);
+}
+
 SEXP ps__kill_if_env(SEXP marker, SEXP after, SEXP pid, SEXP sig) {
   const char *cmarker = CHAR(STRING_ELT(marker, 0));
   pid_t cpid = INTEGER(pid)[0];
