@@ -46,6 +46,8 @@ SEXP psll_connections(SEXP p);
 SEXP ps__os_type();
 SEXP ps__pids();
 SEXP ps__boot_time();
+SEXP ps__cpu_count_logical();
+SEXP ps__cpu_count_physical();
 SEXP ps__users();
 
 /* Generic utils used from R */
